@@ -3,12 +3,15 @@
 import os
 import sys
 
+from lintian_brush.lintian_overrides import override_exists
+
 try:
     patches = set()
     with open('debian/patches/series', 'r') as f:
         for line in f:
             line = line.split('#', 1)[0]
             if not line:
+                patches.add(line.split('#')[1].strip())
                 continue
             patches.add(line.split()[0])
 except FileNotFoundError:
@@ -30,6 +33,10 @@ for patch in os.listdir('debian/patches'):
     # Ignore everything that is listed in series
     if patch in patches:
         continue
+    if override_exists(
+            'patch-file-present-but-not-mentioned-in-series',
+            package='source', info=patch):
+        continue
     removed.add(patch)
     os.unlink(path)
 
