@@ -163,7 +163,8 @@ Arch: all
 class DummyFixer(Fixer):
 
     def run(self, basedir, package, current_version, compat_release,
-            minimum_certainty, trust_package, allow_reformatting, net_access):
+            minimum_certainty, trust_package, allow_reformatting, net_access,
+            opinionated):
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
             f.write('a new line\n')
         return FixerResult("Fixed some tag.\nExtended description.",
@@ -173,7 +174,8 @@ class DummyFixer(Fixer):
 class FailingFixer(Fixer):
 
     def run(self, basedir, package, current_version, compat_release,
-            minimum_certainty, trust_package, allow_reformatting, net_access):
+            minimum_certainty, trust_package, allow_reformatting, net_access,
+            opinionated):
         with open(os.path.join(basedir, 'debian/foo'), 'w') as f:
             f.write("blah")
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
@@ -232,7 +234,7 @@ Arch: all
         class UncertainFixer(Fixer):
             def run(self, basedir, package, current_version, compat_release,
                     minimum_certainty, trust_package, allow_reformatting,
-                    net_access):
+                    net_access, opinionated):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -249,7 +251,7 @@ Arch: all
         class UncertainFixer(Fixer):
             def run(self, basedir, package, current_version, compat_release,
                     minimum_certainty, trust_package, allow_reformatting,
-                    net_access):
+                    net_access, opinionated):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -265,7 +267,7 @@ Arch: all
         class NewFileFixer(Fixer):
             def run(self, basedir, package, current_version, compat_release,
                     minimum_certainty, trust_package, allow_reformatting,
-                    net_access):
+                    net_access, opinionated):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Created new file.", ['some-tag'])
@@ -297,7 +299,7 @@ Arch: all
         class RenameFileFixer(Fixer):
             def run(self, basedir, package, current_version, compat_release,
                     minimum_certainty, trust_package, allow_reformatting,
-                    net_access):
+                    net_access, opinionated):
                 os.rename(os.path.join(basedir, 'debian/control'),
                           os.path.join(basedir, 'debian/control.blah'))
                 return FixerResult("Renamed a file.")
@@ -327,7 +329,7 @@ Arch: all
         class EmptyFixer(Fixer):
             def run(self, basedir, package, current_version, compat_release,
                     minimum_certainty, trust_package, allow_reformatting,
-                    net_access):
+                    net_access, opinionated):
                 return FixerResult("I didn't actually change anything.")
         with tree.lock_write():
             self.assertRaises(
@@ -636,7 +638,7 @@ class LintianBrushVersion(TestCase):
                 'Running outside of source tree?')
         with open('debian/changelog', 'r') as f:
             cl = Changelog(f, max_blocks=1)
-        self.assertEqual(str(cl.version), version_string)
+        self.assertEqual(str(cl.version).split('+')[0], version_string)
 
     def test_matches_setup_version(self):
         if not os.path.exists('setup.py'):
@@ -705,15 +707,17 @@ class CertaintyVsConfidenceTests(TestCase):
 
     def test_confidence_to_certainty(self):
         self.assertEqual("certain", confidence_to_certainty(0))
-        self.assertEqual("likely", confidence_to_certainty(1))
-        self.assertEqual("possible", confidence_to_certainty(2))
+        self.assertEqual("confident", confidence_to_certainty(1))
+        self.assertEqual("likely", confidence_to_certainty(2))
+        self.assertEqual("possible", confidence_to_certainty(3))
         self.assertEqual("unknown", confidence_to_certainty(None))
         self.assertRaises(ValueError, confidence_to_certainty, 2000)
 
     def test_certainty_to_confidence(self):
         self.assertEqual(0, certainty_to_confidence("certain"))
-        self.assertEqual(1, certainty_to_confidence("likely"))
-        self.assertEqual(2, certainty_to_confidence("possible"))
+        self.assertEqual(1, certainty_to_confidence("confident"))
+        self.assertEqual(2, certainty_to_confidence("likely"))
+        self.assertEqual(3, certainty_to_confidence("possible"))
         self.assertIs(None, certainty_to_confidence("unknown"))
         self.assertRaises(ValueError, certainty_to_confidence, "blah")
 
