@@ -44,7 +44,7 @@ from lintian_brush.vcs import (
 from lintian_brush.watch import parse_watch_file
 from urllib.request import urlopen, Request
 
-
+ADDON_ONLY_FIELDS = ['Archive']
 KNOWN_HOSTING_SITES = [
     'code.launchpad.net', 'github.com', 'launchpad.net']
 
@@ -189,6 +189,18 @@ def guess_repo_from_url(url, net_access=False):
     return None
 
 
+def known_bad_guess(datum):
+    if datum.field == 'Bug-Submit':
+        parsed_url = urlparse(datum.value)
+        if parsed_url.hostname == 'bugzilla.gnome.org':
+            return True
+    return False
+
+
+def filter_bad_guesses(guessed_items):
+    return filter(lambda x: not known_bad_guess(x), guessed_items)
+
+
 def update_from_guesses(upstream_metadata, guessed_items):
     for datum in guessed_items:
         current_datum = upstream_metadata.get(datum.field)
@@ -609,18 +621,24 @@ def guess_from_configure(path, trust_package=False):
                     'Name', value.decode(), 'certain', './configure')
             elif key == b'PACKAGE_BUGREPORT':
                 if value in (b'BUG-REPORT-ADDRESS', ):
-                    pass
+                    certainty = 'invalid'
                 elif b'@' in value and not value.endswith(b'gnu.org'):
                     # Downgrade the trustworthiness of this field for most
                     # upstreams if it contains an e-mail address. Most
                     # upstreams seem to just set this to some random address,
                     # and then forget about it.
-                    yield UpstreamDatum(
-                        'Bug-Submit', value.decode(), 'possible',
-                        './configure')
+                    certainty = 'possible'
                 else:
+                    parsed_url = urlparse(value.decode())
+                    if parsed_url.path.strip('/'):
+                        certainty = 'certain'
+                    else:
+                        # It seems unlikely that the bug submit URL lives at
+                        # the root.
+                        certainty = 'possible'
+                if certainty != 'invalid':
                     yield UpstreamDatum(
-                        'Bug-Submit', value.decode(), 'certain', './configure')
+                        'Bug-Submit', value.decode(), certainty, './configure')
             elif key == b'PACKAGE_URL':
                 yield UpstreamDatum(
                     'Homepage', value.decode(), 'certain', './configure')
@@ -747,8 +765,9 @@ def guess_upstream_metadata(
     upstream_metadata = {}
     update_from_guesses(
         upstream_metadata,
-        guess_upstream_metadata_items(
-            path, trust_package=trust_package))
+        filter_bad_guesses(
+            guess_upstream_metadata_items(
+                path, trust_package=trust_package)))
 
     extend_upstream_metadata(
         upstream_metadata, path, net_access=net_access,
@@ -778,10 +797,9 @@ def guess_from_sf(sf_project):
         yield 'Name', data['name']
     if 'external_homepage' in data:
         yield 'Homepage', data['external_homepage']
-    if 'screenshots' in data:
-        screenshot_urls = [s['url'] for s in data['screenshots'] if 'url' in s]
-        if screenshot_urls:
-            yield ('Screenshots', screenshot_urls)
+    # In theory there are screenshots linked from the sourceforge project that
+    # we can use, but if there are multiple "subprojects" then it will be
+    # unclear which one they belong to.
     # TODO(jelmer): What about cvs and bzr?
     VCS_NAMES = ['hg', 'git', 'svn']
     vcs_tools = [
@@ -814,7 +832,7 @@ def extend_from_external_guesser(
 
 def extend_from_sf(upstream_metadata, sf_project):
     # The set of fields that sf can possibly provide:
-    sf_fields = ['Homepage', 'Screenshots', 'Name']
+    sf_fields = ['Homepage', 'Name']
     sf_certainty = upstream_metadata['Archive'].certainty
 
     return extend_from_external_guesser(
@@ -908,6 +926,15 @@ def verify_bug_database_url(url):
     return None
 
 
+def verify_bug_submit_url(url):
+    parsed_url = urlparse(url)
+    if parsed_url.netloc == 'gitlab.com':
+        path = '/'.join(parsed_url.path.strip('/').split('/')[:2])
+        return verify_bug_database_url(
+            urlunparse(parsed_url._replace(path=path)))
+    return None
+
+
 def _extrapolate_repository_from_homepage(upstream_metadata, net_access):
     repo = guess_repo_from_url(
             upstream_metadata['Homepage'].value, net_access=net_access)
@@ -1106,6 +1133,10 @@ def check_upstream_metadata(upstream_metadata, version=None):
     if bug_database and bug_database.certainty == 'likely':
         if verify_bug_database_url(bug_database.value):
             bug_database.certainty = 'certain'
+    bug_submit = upstream_metadata.get('Bug-Submit')
+    if bug_submit and bug_submit.certainty == 'likely':
+        if verify_bug_submit_url(bug_submit.value):
+            bug_submit.certainty = 'certain'
     screenshots = upstream_metadata.get('Screenshots')
     if screenshots and screenshots.certainty == 'likely':
         newvalue = []
